@@ -3,7 +3,7 @@
 from __future__ import unicode_literals, print_function, division
 
 # Static values
-__version__ = '3.19.1'
+__version__ = '3.20.0'
 NAME         = 'xml2rfc'
 VERSION      = [ int(i) if i.isdigit() else i for i in __version__.split('.') ]
 CACHES       = ['/var/cache/xml2rfc', '~/.cache/xml2rfc']  # Ordered by priority
@@ -46,23 +46,14 @@ except (ImportError, OSError, AttributeError):
 def get_versions():
     import sys
     versions = []
-    extras = set(['weasyprint'])
     try:
-        import pkg_resources
-        this = pkg_resources.working_set.by_key[NAME]
-        for p in this.requires():
-            if p.key in extras:
-                extras -= p.key
+        from importlib import metadata
+        from re import split
+        this = metadata.distribution(NAME)
+        for p in [split(r'[\s=<>!]', x)[0] for x in this.requires]:
             try:
-                dist = pkg_resources.get_distribution(p.key)
-                versions.append((dist.project_name, dist.version))
-            except Exception as e:
-                print(e)
-                pass
-        for key in extras:
-            try:
-                dist = pkg_resources.get_distribution(key)
-                versions.append((dist.project_name, dist.version))
+                dist = metadata.distribution(p)
+                versions.append((dist.metadata['name'], dist.metadata['version']))
             except:
                 pass
     except:
