@@ -2,7 +2,7 @@
 
 from __future__ import print_function, unicode_literals
 
-import appdirs
+import platformdirs
 import configargparse
 import datetime
 import io
@@ -87,7 +87,7 @@ def get_pdf_help(missing_libs=""):
 
     2. Next, install weasyprint python modules using pip.
 
-        pip install 'weasyprint>=53.0'
+        pip install 'weasyprint>=53.0,!=57.0,!=60.0'
 
 
     3. Finally, install the full Noto Font and Roboto Mono packages:
@@ -101,8 +101,12 @@ def get_pdf_help(missing_libs=""):
          https://www.google.com/get/noto/help/install/
 
        * Go to https://fonts.google.com/specimen/Roboto+Mono, and download the
-         font.  Follow the installation instructions above, as applied to this
+         font. Follow the installation instructions above, as applied to this
          download.
+
+       * Go to https://fonts.google.com/noto/specimen/Noto+Sans+Math, and
+         download the font. Follow the installation instructions above, as
+         applied to this download.
     
     With these libraries, modules, and fonts installed and available to
     xml2rfc, the --pdf switch will be enabled.
@@ -146,7 +150,7 @@ def main():
     global optionparser
     # Populate options
     config_paths = ['/etc/xml2rfc.conf', '~/.xml2rfc.conf']
-    user_conf = os.path.join(appdirs.user_config_dir(), 'xml2rfc.conf')
+    user_conf = os.path.join(platformdirs.user_config_dir(), 'xml2rfc.conf')
     if not user_conf in config_paths:
         config_paths.append(user_conf)
 
@@ -716,10 +720,11 @@ def main():
             if not filename:
                 filename = basename + '.txt'
                 options.output_filename = filename
-            v2v3 = xml2rfc.V2v3XmlWriter(xmlrfc, options=options, date=options.date)
-            xmlrfc.tree = v2v3.convert2to3()
-            prep = xml2rfc.PrepToolWriter(xmlrfc, options=options, date=options.date, liberal=True, keep_pis=[xml2rfc.V3_PI_TARGET])
-            xmlrfc.tree = prep.prep()
+            if not xmlrfc.tree.getroot().get('prepTime'):
+                v2v3 = xml2rfc.V2v3XmlWriter(xmlrfc, options=options, date=options.date)
+                xmlrfc.tree = v2v3.convert2to3()
+                prep = xml2rfc.PrepToolWriter(xmlrfc, options=options, date=options.date, liberal=True, keep_pis=[xml2rfc.V3_PI_TARGET])
+                xmlrfc.tree = prep.prep()
             if xmlrfc.tree:
                 writer = xml2rfc.TextWriter(xmlrfc, options=options, date=options.date)
                 writer.write(filename)
@@ -731,10 +736,11 @@ def main():
             if not filename:
                 filename = basename + '.html'
                 options.output_filename = filename
-            v2v3 = xml2rfc.V2v3XmlWriter(xmlrfc, options=options, date=options.date)
-            xmlrfc.tree = v2v3.convert2to3()
-            prep = xml2rfc.PrepToolWriter(xmlrfc, options=options, date=options.date, liberal=True, keep_pis=[xml2rfc.V3_PI_TARGET])
-            xmlrfc.tree = prep.prep()
+            if not xmlrfc.tree.getroot().get('prepTime'):
+                v2v3 = xml2rfc.V2v3XmlWriter(xmlrfc, options=options, date=options.date)
+                xmlrfc.tree = v2v3.convert2to3()
+                prep = xml2rfc.PrepToolWriter(xmlrfc, options=options, date=options.date, liberal=True, keep_pis=[xml2rfc.V3_PI_TARGET])
+                xmlrfc.tree = prep.prep()
             if xmlrfc.tree:
                 writer = xml2rfc.HtmlWriter(xmlrfc, options=options, date=options.date)
                 writer.write(filename)
@@ -746,10 +752,11 @@ def main():
             if not filename:
                 filename = basename + '.pdf'
                 options.output_filename = filename
-            v2v3 = xml2rfc.V2v3XmlWriter(xmlrfc, options=options, date=options.date)
-            xmlrfc.tree = v2v3.convert2to3()
-            prep = xml2rfc.PrepToolWriter(xmlrfc, options=options, date=options.date, liberal=True, keep_pis=[xml2rfc.V3_PI_TARGET])
-            xmlrfc.tree = prep.prep()
+            if not xmlrfc.tree.getroot().get('prepTime'):
+                v2v3 = xml2rfc.V2v3XmlWriter(xmlrfc, options=options, date=options.date)
+                xmlrfc.tree = v2v3.convert2to3()
+                prep = xml2rfc.PrepToolWriter(xmlrfc, options=options, date=options.date, liberal=True, keep_pis=[xml2rfc.V3_PI_TARGET])
+                xmlrfc.tree = prep.prep()
             if xmlrfc.tree:
                 writer = xml2rfc.PdfWriter(xmlrfc, options=options, date=options.date)
                 writer.write(filename)
